==> open-xchange-oauth_7.6.0.orig.tar.bz2: open-xchange-oauth-7.6.0/com.openexchange.oauth.json/src/com/openexchange/oauth/json/osgi/OAuthJSONActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.json.osgi;

import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
import com.openexchange.capabilities.CapabilityService;
import com.openexchange.config.ConfigurationService;
import com.openexchange.dispatcher.DispatcherPrefixService;
import com.openexchange.groupware.notify.hostname.HostnameService;
import com.openexchange.oauth.OAuthHTTPClientFactory;
import com.openexchange.oauth.OAuthService;
import com.openexchange.oauth.json.AbstractOAuthAJAXActionService;
import com.openexchange.oauth.json.Services;
import com.openexchange.oauth.json.oauthaccount.actions.AccountActionFactory;
import com.openexchange.oauth.json.oauthmeta.actions.MetaDataActionFactory;
import com.openexchange.oauth.json.proxy.OAuthProxyActionFactory;
import com.openexchange.secret.osgi.tools.WhiteboardSecretService;

/**
 * {@link OAuthJSONActivator} - Activator for JSON OAuth interface.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class OAuthJSONActivator extends AJAXModuleActivator {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(OAuthJSONActivator.class);

    private volatile OSGiOAuthService oAuthService;
    private volatile WhiteboardSecretService secretService;

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ConfigurationService.class, DispatcherPrefixService.class, OAuthService.class, OAuthHTTPClientFactory.class, CapabilityService.class };
    }

    @Override
    public void startBundle() throws Exception {
        try {
            Services.setServiceLookup(this);
            AbstractOAuthAJAXActionService.PREFIX.set(getService(DispatcherPrefixService.class));
            /*
             * Service registrations
             */
            registerModule(AccountActionFactory.getInstance(), "oauth/accounts");
            registerModule(MetaDataActionFactory.getInstance(), "oauth/services");
            registerModule(new OAuthProxyActionFactory(getService(OAuthService.class), getService(OAuthHTTPClientFactory.class)), "oauth/proxy");
            /*
             * Apply OAuth service to actions
             */
            final OSGiOAuthService oAuthService = new OSGiOAuthService().start(context);
            this.oAuthService = oAuthService;
            // registry.addService(OAuthService.class, oAuthService);
            AbstractOAuthAJAXActionService.setOAuthService(oAuthService);
            final WhiteboardSecretService secretService = new WhiteboardSecretService(context);
            this.secretService = secretService;
            secretService.open();
            AbstractOAuthAJAXActionService.setSecretService(secretService);

            getService(CapabilityService.class).declareCapability("oauth");

            trackService(HostnameService.class);
        } catch (final Exception e) {
            LOG.error("", e);
            throw e;
        }
    }

    @Override
    public void stopBundle() throws Exception {
        try {
            final WhiteboardSecretService secretService = this.secretService;
            if (secretService != null) {
                secretService.close();
                this.secretService = null;
            }
            cleanUp();
            final OSGiOAuthService oAuthService = this.oAuthService;
            if (null != oAuthService) {
                oAuthService.stop();
                this.oAuthService = null;
            }
            AbstractOAuthAJAXActionService.setOAuthService(null);
            AbstractOAuthAJAXActionService.PREFIX.set(null);
            Services.setServiceLookup(null);
        } catch (final Exception e) {
            org.slf4j.LoggerFactory.getLogger(OAuthJSONActivator.class).error("", e);
            throw e;
        }
    }

}

==> open-xchange-oauth_7.6.1.orig.tar.bz2: open-xchange-oauth-7.6.1/com.openexchange.oauth.json/src/com/openexchange/oauth/json/osgi/OAuthJSONActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.json.osgi;

import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
import com.openexchange.capabilities.CapabilityService;
import com.openexchange.config.ConfigurationService;
import com.openexchange.dispatcher.DispatcherPrefixService;
import com.openexchange.groupware.notify.hostname.HostnameService;
import com.openexchange.oauth.OAuthHTTPClientFactory;
import com.openexchange.oauth.OAuthService;
import com.openexchange.oauth.OAuthUtilizerCreator;
import com.openexchange.oauth.json.AbstractOAuthAJAXActionService;
import com.openexchange.oauth.json.Services;
import com.openexchange.oauth.json.oauthaccount.actions.AccountActionFactory;
import com.openexchange.oauth.json.oauthmeta.actions.MetaDataActionFactory;
import com.openexchange.oauth.json.proxy.OAuthProxyActionFactory;
import com.openexchange.secret.osgi.tools.WhiteboardSecretService;

/**
 * {@link OAuthJSONActivator} - Activator for JSON OAuth interface.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class OAuthJSONActivator extends AJAXModuleActivator {

    private volatile OSGiOAuthService oAuthService;
    private volatile WhiteboardSecretService secretService;

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ConfigurationService.class, DispatcherPrefixService.class, OAuthService.class, OAuthHTTPClientFactory.class, CapabilityService.class };
    }

    @Override
    public void startBundle() throws Exception {
        try {
            Services.setServiceLookup(this);
            AbstractOAuthAJAXActionService.PREFIX.set(getService(DispatcherPrefixService.class));
            /*
             * Service registrations
             */
            registerModule(AccountActionFactory.getInstance(), "oauth/accounts");
            registerModule(MetaDataActionFactory.getInstance(), "oauth/services");
            registerModule(new OAuthProxyActionFactory(getService(OAuthService.class), getService(OAuthHTTPClientFactory.class)), "oauth/proxy");
            /*
             * Apply OAuth service to actions
             */
            final OSGiOAuthService oAuthService = new OSGiOAuthService().start(context);
            this.oAuthService = oAuthService;
            // registry.addService(OAuthService.class, oAuthService);
            AbstractOAuthAJAXActionService.setOAuthService(oAuthService);
            final WhiteboardSecretService secretService = new WhiteboardSecretService(context);
            this.secretService = secretService;
            secretService.open();
            AbstractOAuthAJAXActionService.setSecretService(secretService);

            getService(CapabilityService.class).declareCapability("oauth");

            trackService(HostnameService.class);
            UtilizerRegistry registry = UtilizerRegistry.initInstance(context);
            track(OAuthUtilizerCreator.class, registry);

            openTrackers();
        } catch (final Exception e) {
            org.slf4j.LoggerFactory.getLogger(OAuthJSONActivator.class).error("", e);
            throw e;
        }
    }

    @Override
    public void stopBundle() throws Exception {
        try {
            super.stopBundle();
            final WhiteboardSecretService secretService = this.secretService;
            if (secretService != null) {
                secretService.close();
                this.secretService = null;
            }
            final OSGiOAuthService oAuthService = this.oAuthService;
            if (null != oAuthService) {
                oAuthService.stop();
                this.oAuthService = null;
            }
            UtilizerRegistry.freeInstance();
            AbstractOAuthAJAXActionService.setOAuthService(null);
            AbstractOAuthAJAXActionService.PREFIX.set(null);
            Services.setServiceLookup(null);
        } catch (final Exception e) {
            org.slf4j.LoggerFactory.getLogger(OAuthJSONActivator.class).error("", e);
            throw e;
        }
    }

}
